| tinythemes-package | R Documentation |
Themes for 'ggplot2' are a convenient way to style plots. The 'hrbrthemes' package contains a particularly nice one, but brings along a significant tail of dependencies. So this (currently experimental) package brings along just the 'theme_ipsum_rc' theme using the 'Roboto' 'Condensed' font. Should the font not be installed on your system, see the help in the package 'hrbrthemes' on how to install 'Roboto Condensed'.
Index: This package was not yet installed at build time.
Dirk Eddelbuettel <edd@debian.org>
Dirk Eddelbuettel [aut, cre] (<https://orcid.org/0000-0001-6419-907X>), Bob Rudis [aut] (<https://orcid.org/0000-0001-5670-2640>)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.